@@ -32,7 +32,7 @@ class AppMenuApplet : public Plasma::Applet
 {
     Q_OBJECT
 
-    Q_PROPERTY(AppMenuModel* model READ model WRITE setModel NOTIFY modelChanged)
+    Q_PROPERTY(AppMenuModel *model READ model WRITE setModel NOTIFY modelChanged)
 
     Q_PROPERTY(int view READ view WRITE setView NOTIFY viewChanged)
 
@@ -43,7 +43,7 @@ class AppMenuApplet : public Plasma::Applet
 public:
     enum ViewType {
         FullView,
-        CompactView
+        CompactView,
     };
 
     explicit AppMenuApplet(QObject *parent, const QVariantList &data);
@@ -80,7 +80,6 @@ private:
     void setCurrentIndex(int currentIndex);
     void onMenuAboutToHide();
 
-
     int m_currentIndex = -1;
     int m_viewType = FullView;
     QPointer<QMenu> m_currentMenu;
