@@ -20,19 +20,15 @@
 #include "notificationaction.h"
 #include "notificationsengine.h"
 
-NotificationService::NotificationService(NotificationsEngine* parent, const QString& source)
-    : Plasma::Service(parent),
-      m_notificationEngine(parent)
+NotificationService::NotificationService(NotificationsEngine *parent, const QString &source)
+    : Plasma::Service(parent)
+    , m_notificationEngine(parent)
 {
     setName(QStringLiteral("notifications"));
     setDestination(source);
 }
 
-Plasma::ServiceJob* NotificationService::createJob(const QString& operation,
-                                                   QMap<QString,QVariant>& parameters)
+Plasma::ServiceJob *NotificationService::createJob(const QString &operation, QMap<QString, QVariant> &parameters)
 {
     return new NotificationAction(m_notificationEngine, destination(), operation, parameters, this);
 }
-
-
-
