@@ -28,6 +28,7 @@ public:
     explicit Private(UpdateLaunchEnvJob *q);
     void monitorReply(const QDBusPendingReply<> &reply);
 
+    static bool isPosixName(const QString &name);
     static bool isSystemdApprovedValue(const QString &value);
 
     UpdateLaunchEnvJob *q;
@@ -38,7 +39,6 @@ public:
 UpdateLaunchEnvJob::Private::Private(UpdateLaunchEnvJob *q)
     : q(q)
 {
-
 }
 
 void UpdateLaunchEnvJob::Private::monitorReply(const QDBusPendingReply<> &reply)
@@ -82,23 +82,22 @@ void UpdateLaunchEnvJob::start()
     QStringList systemdUpdates;
 
     for (const auto &varName : d->environment.keys()) {
+        if (!Private::isPosixName(varName)) {
+            qWarning() << "Skipping syncing of environment variable " << varName << "as name contains unsupported characters";
+            continue;
+        }
         const QString value = d->environment.value(varName);
 
         // KLauncher
-        org::kde::KLauncher klauncher(QStringLiteral("org.kde.klauncher5"),
-                                    QStringLiteral("/KLauncher"),
-                                    QDBusConnection::sessionBus());
+        org::kde::KLauncher klauncher(QStringLiteral("org.kde.klauncher5"), QStringLiteral("/KLauncher"), QDBusConnection::sessionBus());
         auto klauncherReply = klauncher.setLaunchEnv(varName, value);
         d->monitorReply(klauncherReply);
 
         // plasma-session
-        org::kde::Startup startup(QStringLiteral("org.kde.Startup"),
-                                QStringLiteral("/Startup"),
-                                QDBusConnection::sessionBus());
+        org::kde::Startup startup(QStringLiteral("org.kde.Startup"), QStringLiteral("/Startup"), QDBusConnection::sessionBus());
         auto startupReply = startup.updateLaunchEnv(varName, value);
         d->monitorReply(startupReply);
 
-
         // DBus-activation environment
         dbusActivationEnv.insert(varName, value);
 
@@ -126,16 +125,34 @@ void UpdateLaunchEnvJob::start()
 
     // _user_ systemd env
     QDBusMessage systemdActivationMsg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
-                                                                    QStringLiteral("/org/freedesktop/systemd1"),
-                                                                    QStringLiteral("org.freedesktop.systemd1.Manager"),
-                                                                    QStringLiteral("SetEnvironment"));
+                                                                       QStringLiteral("/org/freedesktop/systemd1"),
+                                                                       QStringLiteral("org.freedesktop.systemd1.Manager"),
+                                                                       QStringLiteral("SetEnvironment"));
     systemdActivationMsg.setArguments({systemdUpdates});
 
-
     auto systemdActivationReply = QDBusConnection::sessionBus().asyncCall(systemdActivationMsg);
     d->monitorReply(systemdActivationReply);
 }
 
+bool UpdateLaunchEnvJob::Private::isPosixName(const QString &name)
+{
+    // Posix says characters like % should be 'tolerated', but it gives issues in practice.
+    // https://bugzilla.redhat.com/show_bug.cgi?id=1754395
+    // https://bugzilla.redhat.com/show_bug.cgi?id=1879216
+    // Ensure systemd compat by only allowing alphanumerics and _ in names.
+    bool first = true;
+    for (const QChar c : name) {
+        if (first && !c.isLetter() && c != QChar('_')) {
+            return false;
+        } else if (first) {
+            first = false;
+        } else if (!c.isLetterOrNumber() && c != QChar('_')) {
+            return false;
+        }
+    }
+    return !first;
+}
+
 bool UpdateLaunchEnvJob::Private::isSystemdApprovedValue(const QString &value)
 {
     // systemd code checks that a value contains no control characters except \n \t
