@@ -24,49 +24,48 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "shutdowndlg.h"
 
 #include <QApplication>
-#include <QQuickItem>
-#include <QTimer>
-#include <QFile>
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusPendingCall>
 #include <QDBusPendingCallWatcher>
 #include <QDBusPendingReply>
 #include <QDBusVariant>
-#include <QQuickView>
+#include <QFile>
+#include <QPainter>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QQmlPropertyMap>
-#include <QPainter>
-#include <QStandardPaths>
-#include <QX11Info>
+#include <QQuickItem>
+#include <QQuickView>
 #include <QScreen>
+#include <QStandardPaths>
+#include <QTimer>
+#include <QX11Info>
 
 #include <KPackage/Package>
 #include <KPackage/PackageLoader>
 
 #include <KAuthorized>
+#include <KConfigGroup>
+#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
+#include <KSharedConfig>
 #include <KUser>
-#include <Solid/PowerManagement>
 #include <KWindowEffects>
 #include <KWindowSystem>
-#include <KDeclarative/KDeclarative>
-#include <KSharedConfig>
-#include <KConfigGroup>
 
-#include <stdio.h>
 #include <netwm.h>
+#include <stdio.h>
 
-#include <X11/Xutil.h>
 #include <X11/Xatom.h>
+#include <X11/Xutil.h>
 #include <fixx11h.h>
 
 #include <config-workspace.h>
 #include <debug.h>
 
-#include <KWayland/Client/surface.h>
 #include <KWayland/Client/plasmashell.h>
+#include <KWayland/Client/surface.h>
 
 static const QString s_login1Service = QStringLiteral("org.freedesktop.login1");
 static const QString s_login1Path = QStringLiteral("/org/freedesktop/login1");
@@ -74,16 +73,12 @@ static const QString s_dbusPropertiesInterface = QStringLiteral("org.freedesktop
 static const QString s_login1ManagerInterface = QStringLiteral("org.freedesktop.login1.Manager");
 static const QString s_login1RebootToFirmwareSetup = QStringLiteral("RebootToFirmwareSetup");
 
-Q_DECLARE_METATYPE(Solid::PowerManagement::SleepState)
-
-KSMShutdownDlg::KSMShutdownDlg(QWindow* parent,
-                                bool maysd, KWorkSpace::ShutdownType sdtype,
-                                KWayland::Client::PlasmaShell *plasmaShell)
-  : QuickViewSharedEngine(parent),
-    m_result(false),
-    m_waylandPlasmaShell(plasmaShell)
-    // this is a WType_Popup on purpose. Do not change that! Not
-    // having a popup here has severe side effects.
+KSMShutdownDlg::KSMShutdownDlg(QWindow *parent, KWorkSpace::ShutdownType sdtype, KWayland::Client::PlasmaShell *plasmaShell)
+    : QuickViewSharedEngine(parent)
+    , m_result(false)
+    , m_waylandPlasmaShell(plasmaShell)
+// this is a WType_Popup on purpose. Do not change that! Not
+// having a popup here has severe side effects.
 {
     // window stuff
     setClearBeforeRendering(true);
@@ -92,22 +87,27 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow* parent,
     setResizeMode(KQuickAddons::QuickViewSharedEngine::SizeRootObjectToView);
 
     // Qt doesn't set this on unmanaged windows
-    //FIXME: or does it?
+    // FIXME: or does it?
     if (KWindowSystem::isPlatformX11()) {
-        XChangeProperty( QX11Info::display(), winId(),
-            XInternAtom( QX11Info::display(), "WM_WINDOW_ROLE", False ), XA_STRING, 8, PropModeReplace,
-            (unsigned char *)"logoutdialog", strlen( "logoutdialog" ));
+        XChangeProperty(QX11Info::display(),
+                        winId(),
+                        XInternAtom(QX11Info::display(), "WM_WINDOW_ROLE", False),
+                        XA_STRING,
+                        8,
+                        PropModeReplace,
+                        (unsigned char *)"logoutdialog",
+                        strlen("logoutdialog"));
 
         XClassHint classHint;
-        classHint.res_name = const_cast<char*>("ksmserver");
-        classHint.res_class = const_cast<char*>("ksmserver");
+        classHint.res_name = const_cast<char *>("ksmserver");
+        classHint.res_class = const_cast<char *>("ksmserver");
         XSetClassHint(QX11Info::display(), winId(), &classHint);
     }
 
-    //QQuickView *windowContainer = QQuickView::createWindowContainer(m_view, this);
-    //windowContainer->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    // QQuickView *windowContainer = QQuickView::createWindowContainer(m_view, this);
+    // windowContainer->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
     QQmlContext *context = rootContext();
-    context->setContextProperty(QStringLiteral("maysd"), maysd);
+    context->setContextProperty(QStringLiteral("maysd"), m_session.canShutdown());
     context->setContextProperty(QStringLiteral("sdtype"), sdtype);
 
     QQmlPropertyMap *mapShutdownType = new QQmlPropertyMap(this);
@@ -119,12 +119,11 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow* parent,
     context->setContextProperty(QStringLiteral("ShutdownType"), mapShutdownType);
 
     QQmlPropertyMap *mapSpdMethods = new QQmlPropertyMap(this);
-    QSet<Solid::PowerManagement::SleepState> spdMethods = Solid::PowerManagement::supportedSleepStates();
-    mapSpdMethods->insert(QStringLiteral("StandbyState"), QVariant::fromValue(spdMethods.contains(Solid::PowerManagement::StandbyState)));
-    mapSpdMethods->insert(QStringLiteral("SuspendState"), QVariant::fromValue(spdMethods.contains(Solid::PowerManagement::SuspendState)));
-    mapSpdMethods->insert(QStringLiteral("HibernateState"), QVariant::fromValue(spdMethods.contains(Solid::PowerManagement::HibernateState)));
+    mapSpdMethods->insert(QStringLiteral("StandbyState"), m_session.canSuspend());
+    mapSpdMethods->insert(QStringLiteral("SuspendState"), m_session.canSuspend());
+    mapSpdMethods->insert(QStringLiteral("HibernateState"), m_session.canHibernate());
     context->setContextProperty(QStringLiteral("spdMethods"), mapSpdMethods);
-    context->setContextProperty(QStringLiteral("canLogout"), KAuthorized::authorize(QStringLiteral("logout")));
+    context->setContextProperty(QStringLiteral("canLogout"), m_session.canLogout());
 
     // Trying to access a non-existent context property throws an error, always create the property and then update it later
     context->setContextProperty("rebootToFirmwareSetup", false);
@@ -145,7 +144,7 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow* parent,
     // TODO KF6 remove, used to read "BootManager" from kdmrc
     context->setContextProperty(QStringLiteral("bootManager"), QStringLiteral("None"));
 
-    //TODO KF6 remove. Unused
+    // TODO KF6 remove. Unused
     context->setContextProperty(QStringLiteral("choose"), false);
 
     // TODO KF6 remove, used to call KDisplayManager::bootOptions
@@ -159,8 +158,8 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow* parent,
     // engine stuff
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(engine());
-    kdeclarative.setupBindings();
-//    windowContainer->installEventFilter(this);
+    kdeclarative.setupEngine(engine());
+    engine()->rootContext()->setContextObject(new KLocalizedContext(engine()));
 }
 
 void KSMShutdownDlg::init()
@@ -168,7 +167,6 @@ void KSMShutdownDlg::init()
     rootContext()->setContextProperty(QStringLiteral("screenGeometry"), screen()->geometry());
 
     QString fileName;
-    QString fileUrl;
     KPackage::Package package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
     KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("kdeglobals")), "KDE");
     const QString packageName = cg.readEntry("LookAndFeelPackage", QString());
@@ -185,15 +183,15 @@ void KSMShutdownDlg::init()
         return;
     }
 
-    if(!errors().isEmpty()) {
+    if (!errors().isEmpty()) {
         qCWarning(LOGOUT_GREETER) << errors();
     }
 
     connect(rootObject(), SIGNAL(logoutRequested()), SLOT(slotLogout()));
     connect(rootObject(), SIGNAL(haltRequested()), SLOT(slotHalt()));
-    connect(rootObject(), SIGNAL(suspendRequested(int)), SLOT(slotSuspend(int)) );
+    connect(rootObject(), SIGNAL(suspendRequested(int)), SLOT(slotSuspend(int)));
     connect(rootObject(), SIGNAL(rebootRequested()), SLOT(slotReboot()));
-    connect(rootObject(), SIGNAL(rebootRequested2(int)), SLOT(slotReboot(int)) );
+    connect(rootObject(), SIGNAL(rebootRequested2(int)), SLOT(slotReboot(int)));
     connect(rootObject(), SIGNAL(cancelRequested()), SLOT(reject()));
     connect(rootObject(), SIGNAL(lockScreenRequested()), SLOT(slotLockScreen()));
 
@@ -201,39 +199,36 @@ void KSMShutdownDlg::init()
         setGeometry(screen()->geometry());
     });
 
-    //decide in backgroundcontrast whether doing things darker or lighter
-    //set backgroundcontrast here, because in QEvent::PlatformSurface
-    //is too early and we don't have the root object yet
+    // decide in backgroundcontrast whether doing things darker or lighter
+    // set backgroundcontrast here, because in QEvent::PlatformSurface
+    // is too early and we don't have the root object yet
     const QColor backgroundColor = rootObject() ? rootObject()->property("backgroundColor").value<QColor>() : QColor();
-    KWindowEffects::enableBackgroundContrast(winId(), true,
-        0.4,
-        (backgroundColor.value() > 128 ? 1.6 : 0.3),
-        1.7);
+    KWindowEffects::enableBackgroundContrast(winId(), true, 0.4, (backgroundColor.value() > 128 ? 1.6 : 0.3), 1.7);
     KQuickAddons::QuickViewSharedEngine::showFullScreen();
     setFlag(Qt::FramelessWindowHint);
     requestActivate();
 
-    KWindowSystem::setState(winId(), NET::SkipTaskbar|NET::SkipPager);
+    KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
 
     setKeyboardGrabEnabled(true);
 }
 
 void KSMShutdownDlg::resizeEvent(QResizeEvent *e)
 {
-    KQuickAddons::QuickViewSharedEngine::resizeEvent( e );
+    KQuickAddons::QuickViewSharedEngine::resizeEvent(e);
 
-    if( KWindowSystem::compositingActive()) {
-        //TODO: reenable window mask when we are without composite?
-//        clearMask();
+    if (KWindowSystem::compositingActive()) {
+        // TODO: reenable window mask when we are without composite?
+        //        clearMask();
     } else {
-//        setMask(m_view->mask());
+        //        setMask(m_view->mask());
     }
 }
 
 bool KSMShutdownDlg::event(QEvent *e)
 {
     if (e->type() == QEvent::PlatformSurface) {
-        switch (static_cast<QPlatformSurfaceEvent*>(e)->surfaceEventType()) {
+        switch (static_cast<QPlatformSurfaceEvent *>(e)->surfaceEventType()) {
         case QPlatformSurfaceEvent::SurfaceCreated:
             setupWaylandIntegration();
             KWindowEffects::enableBlurBehind(winId(), true);
@@ -273,7 +268,7 @@ void KSMShutdownDlg::setupWaylandIntegration()
 
 void KSMShutdownDlg::slotLogout()
 {
-    m_shutdownType = KWorkSpace::ShutdownTypeNone;
+    m_session.requestLogout(SessionManagement::ConfirmationMode::Skip);
     accept();
 }
 
@@ -281,7 +276,7 @@ void KSMShutdownDlg::slotReboot()
 {
     // no boot option selected -> current
     m_bootOption.clear();
-    m_shutdownType = KWorkSpace::ShutdownTypeReboot;
+    m_session.requestReboot(SessionManagement::ConfirmationMode::Skip);
     accept();
 }
 
@@ -289,26 +284,21 @@ void KSMShutdownDlg::slotReboot(int opt)
 {
     if (int(rebootOptions.size()) > opt)
         m_bootOption = rebootOptions[opt];
-    m_shutdownType = KWorkSpace::ShutdownTypeReboot;
+    m_session.requestReboot(SessionManagement::ConfirmationMode::Skip);
     accept();
 }
 
-
 void KSMShutdownDlg::slotLockScreen()
 {
     m_bootOption.clear();
-    QDBusMessage call = QDBusMessage::createMethodCall(QStringLiteral("org.kde.screensaver"),
-                                                       QStringLiteral("/ScreenSaver"),
-                                                       QStringLiteral("org.freedesktop.ScreenSaver"),
-                                                       QStringLiteral("Lock"));
-    QDBusConnection::sessionBus().asyncCall(call);
+    m_session.lock();
     reject();
 }
 
 void KSMShutdownDlg::slotHalt()
 {
     m_bootOption.clear();
-    m_shutdownType = KWorkSpace::ShutdownTypeHalt;
+    m_session.requestShutdown(SessionManagement::ConfirmationMode::Skip);
     accept();
 }
 
@@ -316,13 +306,13 @@ void KSMShutdownDlg::slotSuspend(int spdMethod)
 {
     m_bootOption.clear();
     switch (spdMethod) {
-        case Solid::PowerManagement::StandbyState:
-        case Solid::PowerManagement::SuspendState:
-            Solid::PowerManagement::requestSleep(Solid::PowerManagement::SuspendState, nullptr, nullptr);
-            break;
-        case Solid::PowerManagement::HibernateState:
-            Solid::PowerManagement::requestSleep(Solid::PowerManagement::HibernateState, nullptr, nullptr);
-            break;
+    case 1: // Solid::PowerManagement::StandbyState:
+    case 2: // Solid::PowerManagement::SuspendState:
+        m_session.suspend();
+        break;
+    case 4: // Solid::PowerManagement::HibernateState:
+        m_session.hibernate();
+        break;
     }
     reject();
 }
