@@ -24,22 +24,22 @@
 #include <QSortFilterProxyModel>
 #include <QVector>
 
-class SlideFilterModel : public QSortFilterProxyModel {
-
+class SlideFilterModel : public QSortFilterProxyModel
+{
     Q_OBJECT
 
     Q_PROPERTY(bool usedInConfig MEMBER m_usedInConfig NOTIFY usedInConfigChanged);
 
 public:
-    SlideFilterModel(QObject* parent);
-    bool lessThan(const QModelIndex& source_left, const QModelIndex& source_right) const override;
-    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const override;
+    SlideFilterModel(QObject *parent);
+    bool lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const override;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
     void setSourceModel(QAbstractItemModel *sourceModel) override;
     void setSortingMode(Image::SlideshowMode mode);
     void invalidate();
     void invalidateFilter();
 
-    Q_INVOKABLE int indexOf(const QString& path);
+    Q_INVOKABLE int indexOf(const QString &path);
     Q_INVOKABLE void openContainingFolder(int rowIndex);
 
 Q_SIGNALS:
